@@ -6,3 +6,6 @@ df = pd.DataFrame(data=d)
 def add_blank_column(dataframe,column_name):
     dataframe[f'{column_name}'] = ''
     return dataframe
+
+def add_5(num):
+    return num + 5
\ No newline at end of file
